@@ -2,7 +2,7 @@
  *
  *
  *
- * Copyright (C) 1997-2012 by Dimitri van Heesch.
+ * Copyright (C) 1997-2015 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby
@@ -42,7 +42,7 @@
  Translator class (by the local maintainer) when the localized
  translator is made up-to-date again.
 */
-class TranslatorEsperanto : public Translator
+class TranslatorEsperanto : public TranslatorAdapter_1_8_4
 {
   public:
 
@@ -76,12 +76,6 @@ class TranslatorEsperanto : public Translator
       return "\\usepackage[esperanto]{babel}\n";
     }
 
-    /*! return the language charset. This will be used for the HTML output */
-    virtual QCString idLanguageCharset()
-    {
-      return "utf-8";
-    }
-
     // --- Language translation methods -------------------
 
     /*! used in the compound documentation before a list of related functions. */
@@ -127,7 +121,7 @@ class TranslatorEsperanto : public Translator
 
     /*! put in the class documentation */
     virtual QCString trListOfAllMembers()
-    { return "Listo de ĉiuj membroj."; }
+    { return "Listo de ĉiuj membroj"; }
 
     /*! used as the title of the "list of all members" page of a class */
     virtual QCString trMemberList()
@@ -424,12 +418,6 @@ class TranslatorEsperanto : public Translator
     virtual QCString trDefines()
     { return "Difinoj"; }
 
-    /*! This is used in the documentation of a file as a header before the
-     *  list of function prototypes
-     */
-    virtual QCString trFuncProtos()
-    { return "Funkciaj Prototipoj"; }
-
     /*! This is used in the documentation of a file as a header before the
      *  list of typedefs
      */
@@ -466,12 +454,6 @@ class TranslatorEsperanto : public Translator
     virtual QCString trDefineDocumentation()
     { return "Difina Dokumentado"; }
 
-    /*! This is used in the documentation of a file/namespace before the list
-     *  of documentation blocks for function prototypes
-     */
-    virtual QCString trFunctionPrototypeDocumentation()
-    { return "Dokumentado de Funkciaj Prototipoj"; }
-
     /*! This is used in the documentation of a file/namespace before the list
      *  of documentation blocks for typedefs
      */
@@ -521,12 +503,6 @@ class TranslatorEsperanto : public Translator
       result+=(QCString)" de";
       return result;
     }
-    /*! This is part of the sentence used in the standard footer of each page.
-     */
-    virtual QCString trWrittenBy()
-    {
-      return "skribita de";
-    }
 
     /*! this text is put before a class diagram */
     virtual QCString trClassDiagram(const char *clName)
@@ -623,6 +599,7 @@ class TranslatorEsperanto : public Translator
         case ClassDef::Protocol:   result+="protokolo "; break;
         case ClassDef::Category:   result+="kategorio "; break;
         case ClassDef::Exception:  result+="escepto "; break;
+        default: break;
       }
       result+=(QCString)clName;
       return result;
@@ -780,6 +757,7 @@ class TranslatorEsperanto : public Translator
         case ClassDef::Protocol:   result+="protokolo"; break;
         case ClassDef::Category:   result+="kategorio"; break;
         case ClassDef::Exception:  result+="escepto"; break;
+        default: break;
       }
       result+=" generitas el la ";
       if (single) result+="sekva dosiero:";
@@ -787,12 +765,6 @@ class TranslatorEsperanto : public Translator
       return result;
     }
 
-    /*! This is in the (quick) index as a link to the alphabetical compound
-     * list.
-     */
-    virtual QCString trAlphabeticalList()
-    { return "Alfabeta Listo"; }
-
 //////////////////////////////////////////////////////////////////////////
 // new since 0.49-990901
 //////////////////////////////////////////////////////////////////////////
@@ -1045,7 +1017,7 @@ class TranslatorEsperanto : public Translator
         "};\n"
         "\\endcode\n"
         "Tio ĉi liveros la sekvan diagramon:"
-        "<p><center><img alt=\"\" src=\"graph_legend."+Config_getEnum("DOT_IMAGE_FORMAT")+"\"></center>\n"
+        "<p><center><img alt=\"\" src=\"graph_legend."+getDotImageExtension()+"\"></center>\n"
         "<p>\n"
         "La skatoloj de la supra diagramo havas la sekvajn signifojn:\n"
         "<ul>\n"
@@ -1092,16 +1064,6 @@ class TranslatorEsperanto : public Translator
       return "Testa Listo";
     }
 
-//////////////////////////////////////////////////////////////////////////
-// new since 1.2.1
-//////////////////////////////////////////////////////////////////////////
-
-    /*! Used as a section header for KDE-2 IDL methods */
-    virtual QCString trDCOPMethods()
-    {
-      return "DCOP Membraj Funkcioj";
-    }
-
 //////////////////////////////////////////////////////////////////////////
 // new since 1.2.2
 //////////////////////////////////////////////////////////////////////////
@@ -1445,14 +1407,6 @@ class TranslatorEsperanto : public Translator
 // new since 1.3.3
 //////////////////////////////////////////////////////////////////////////
 
-    /*! When the search engine is enabled this text is put in the header
-     *  of each page before the field where one can enter the text to search
-     *  for.
-     */
-    virtual QCString trSearchForIndex()
-    {
-      return "Serĉi";
-    }
     /*! This string is used as the title for the page listing the search
      *  results.
      */
@@ -1679,6 +1633,7 @@ class TranslatorEsperanto : public Translator
         case ClassDef::Protocol:   result+="protokolo "; break;
         case ClassDef::Category:   result+="kategorio "; break;
         case ClassDef::Exception:  result+="escepto "; break;
+        default: break;
       }
       result+=(QCString)clName;
       return result;
@@ -1745,6 +1700,7 @@ class TranslatorEsperanto : public Translator
         case ClassDef::Protocol:   result+="protokolo"; break;
         case ClassDef::Category:   result+="kategorio"; break;
         case ClassDef::Exception:  result+="escepto"; break;
+        default: break;
       }
       result+=" kreiĝis el la ";
       if (single) result+="sekva dosiero:"; else result+="sekvaj dosieroj:";
@@ -1815,12 +1771,6 @@ class TranslatorEsperanto : public Translator
 // new since 1.6.3 (missing items for the directory pages)
 //////////////////////////////////////////////////////////////////////////
 
-    /*! introduction text for the directory dependency graph */
-    virtual QCString trDirDependency(const char *name)
-    {
-      return (QCString)"Diagramo de dependecoj dosierujaj por "+name;
-    }
-
     /*! when clicking a directory dependency label, a page with a
      *  table is shown. The heading for the first column mentions the
      *  source file that has a relation to another file.
@@ -1928,6 +1878,69 @@ class TranslatorEsperanto : public Translator
     virtual QCString trAdditionalInheritedMembers()
     { return "Kromaj Hereditaj Membroj"; }
 
+//////////////////////////////////////////////////////////////////////////
+// new since 1.8.2
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used as a tooltip for the toggle button that appears in the
+     *  navigation tree in the HTML output when GENERATE_TREEVIEW is
+     *  enabled. This tooltip explains the meaning of the button.
+     */
+    virtual QCString trPanelSynchronisationTooltip(bool enable)
+    {
+      QCString opt = enable ? "aktivigi" : "malaktivigi";
+      return "klaku por "+opt+" panelan sinkronigon";
+    }
+
+    /*! Used in a method of an Objective-C class that is declared in a
+     *  a category. Note that the @1 marker is required and is replaced
+     *  by a link.
+     */
+    virtual QCString trProvidedByCategory()
+    {
+      return "Provizita de kategorio @1.";
+    }
+
+    /*! Used in a method of an Objective-C category that extends a class.
+     *  Note that the @1 marker is required and is replaced by a link to
+     *  the class method.
+     */
+    virtual QCString trExtendsClass()
+    {
+      return "Etendi klason @1.";
+    }
+
+    /*! Used as the header of a list of class methods in Objective-C.
+     *  These are similar to static public member functions in C++.
+     */
+    virtual QCString trClassMethods()
+    {
+      return "Klasaj Metodoj";
+    }
+
+    /*! Used as the header of a list of instance methods in Objective-C.
+     *  These are similar to public member functions in C++.
+     */
+    virtual QCString trInstanceMethods()
+    {
+      return "Aperaj Metodoj";
+    }
+
+    /*! Used as the header of the member functions of an Objective-C class.
+     */
+    virtual QCString trMethodDocumentation()
+    {
+      return "Dokumentaro de la Metodo";
+    }
+
+    /*! Used as the title of the design overview picture created for the
+     *  VHDL output.
+     */
+    virtual QCString trDesignOverview()
+    {
+      return "Fasona Superrigardo";
+    }
+
 //////////////////////////////////////////////////////////////////////////
 
 };
