@@ -2,7 +2,7 @@
  *
  *
  *
- * Copyright (C) 1997-2012 by Dimitri van Heesch.
+ * Copyright (C) 1997-2015 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby
@@ -41,7 +41,7 @@
 // Translator class (by the local maintainer) when the localized
 // translator is made up-to-date again.
 
-class TranslatorChinesetraditional : public TranslatorAdapter_1_8_0
+class TranslatorChinesetraditional : public Translator
 {
   public:
 
@@ -75,12 +75,6 @@ class TranslatorChinesetraditional : public TranslatorAdapter_1_8_0
       return "";
     }
 
-    /*! return the language charset. This will be used for the HTML output */
-    virtual QCString idLanguageCharset()
-    {
-      return "big5";
-    }
-
     // --- Language translation methods -------------------
 
     /*! used in the compound documentation before a list of related functions. */
@@ -423,12 +417,6 @@ class TranslatorChinesetraditional : public TranslatorAdapter_1_8_0
     virtual QCString trDefines()
     { return "定義"; }
 
-    /*! This is used in the documentation of a file as a header before the
-     *  list of function prototypes
-     */
-    virtual QCString trFuncProtos()
-    { return "函式原型"; }
-
     /*! This is used in the documentation of a file as a header before the
      *  list of typedefs
      */
@@ -465,12 +453,6 @@ class TranslatorChinesetraditional : public TranslatorAdapter_1_8_0
     virtual QCString trDefineDocumentation()
     { return "定義巨集說明文件"; }
 
-    /*! This is used in the documentation of a file/namespace before the list
-     *  of documentation blocks for function prototypes
-     */
-    virtual QCString trFunctionPrototypeDocumentation()
-    { return "函式原型說明文件"; }
-
     /*! This is used in the documentation of a file/namespace before the list
      *  of documentation blocks for typedefs
      */
@@ -526,12 +508,6 @@ class TranslatorChinesetraditional : public TranslatorAdapter_1_8_0
       result+=(QCString)", 產生器:";
       return result;
     }
-    /*! This is part of the sentence used in the standard footer of each page.
-     */
-    virtual QCString trWrittenBy()
-    {
-      return "撰寫人:";
-    }
 
     /*! this text is put before a class diagram */
     virtual QCString trClassDiagram(const char *clName)
@@ -624,9 +600,10 @@ class TranslatorChinesetraditional : public TranslatorAdapter_1_8_0
         case ClassDef::Struct:     result+=" 結構"; break;
         case ClassDef::Union:      result+=" 聯合"; break;
         case ClassDef::Interface:  result+=" 介面"; break;
-        case ClassDef::Protocol:   result+=" 協定"; break; 
+        case ClassDef::Protocol:   result+=" 協定"; break;
         case ClassDef::Category:   result+=" 分類"; break;
         case ClassDef::Exception:  result+=" 例外"; break;
+        default: break;
       }
       if (isTemplate) result+=" 樣版";
       result+=" 參考文件";
@@ -786,18 +763,13 @@ class TranslatorChinesetraditional : public TranslatorAdapter_1_8_0
         case ClassDef::Protocol:   result+="協定(protocol)"; break;
         case ClassDef::Category:   result+="分類(category)"; break;
         case ClassDef::Exception:  result+="例外(exception)"; break;
+        default: break;
       }
       result+=" 文件是由下列檔案中產生";
       if (single) result+=":"; else result+=":";
       return result;
     }
 
-    /*! This is in the (quick) index as a link to the alphabetical compound
-     * list.
-     */
-    virtual QCString trAlphabeticalList()
-    { return "字母順序列表"; }
-
 //////////////////////////////////////////////////////////////////////////
 // new since 0.49-990901
 //////////////////////////////////////////////////////////////////////////
@@ -1022,7 +994,7 @@ class TranslatorChinesetraditional : public TranslatorAdapter_1_8_0
         ".<p>\n"
         "請看下面範例:\n"
         "\\code\n"
-        "/*! 因為截斷的不可見類別 */\n"
+        "/*! 因為截斷而造成的不可見類別 */\n"
         "class Invisible { };\n\n"
         "/*! 截斷的類別, 繼承關係被隱藏 */\n"
         "class Truncated : public Invisible { };\n\n"
@@ -1049,32 +1021,32 @@ class TranslatorChinesetraditional : public TranslatorAdapter_1_8_0
         "    Used *m_usedClass;\n"
         "};\n"
         "\\endcode\n"
-        "若在組態檔中的 \\c MAX_DOT_GRAPH_HEIGHT tag "
-        "設為 240，將會產生下列的圖示:"
-        "<p><center><img src=\"graph_legend."+Config_getEnum("DOT_IMAGE_FORMAT")+"\"></center>\n"
+        "這個例子會產生下列的圖示:"
+        "<p><center><img alt=\"\" src=\"graph_legend."+getDotImageExtension()+"\"></center></p>\n"
         "<p>\n"
         "上圖中的各區塊意義如下:\n"
+        "</p>\n"
         "<ul>\n"
         "<li>%A 填滿黑色的區塊代表產生這個圖示的類別或結構 "
         ".\n"
-        "<li>%A 黑邊的區塊代表文件化過的結構或類別.\n"
-        "<li>%A 灰邊的區塊代表未經文件化的結構或是類別.\n"
+        "<li>%A 黑邊的區塊代表文件化過的結構或類別.</li>\n"
+        "<li>%A 灰邊的區塊代表未經文件化的結構或是類別.</li>\n"
         "<li>%A 紅邊的區塊代表文件化的結構或是類別，"
         "這些結構或類別的繼承或包含關係不會全部顯示. %A 圖示 "
-        "若無法塞入指定的邊界中將會被截斷.\n"
+        "若無法塞入指定的邊界中將會被截斷.</li>\n"
         "</ul>\n"
+        "<p>\n"
         "箭頭具有下面的意義:\n"
+        "</p>\n"
         "<ul>\n"
         "<li>%A 深藍色箭頭用來代表兩個類別間的公開繼承 "
         "關係.\n"
-        "<li>%A 深綠色箭頭代表保護繼承.\n"
-        "<li>%A 深紅色箭頭代表私有繼承.\n"
+        "<li>%A 深綠色箭頭代表保護繼承。</li>\n"
+        "<li>%A 深紅色箭頭代表私有繼承。</li>\n"
         "<li>%A 紫色箭頭用來表示類別被另一個包含或是使用."
-        "箭頭上標示著可存取該類別或是結構的對應變數"
-        ".\n"
+        "箭頭上標示著可存取該類別或是結構的對應變數。</li>\n"
         "<li>%A 黃色箭頭代表樣版實體與樣版類別之間的關係。"
-        "箭頭上標記著樣版實體上的參數"
-        ".\n"
+        "箭頭上標記著樣版實體上的參數。</li>\n"
         "</ul>\n";
     }
     /*! text for the link to the legend page */
@@ -1098,16 +1070,6 @@ class TranslatorChinesetraditional : public TranslatorAdapter_1_8_0
       return "測試項目列表";
     }
 
-//////////////////////////////////////////////////////////////////////////
-// new since 1.2.1
-//////////////////////////////////////////////////////////////////////////
-
-    /*! Used as a section header for KDE-2 IDL methods */
-    virtual QCString trDCOPMethods()
-    {
-      return "DCOP方法";
-    }
-
 //////////////////////////////////////////////////////////////////////////
 // new since 1.2.2
 //////////////////////////////////////////////////////////////////////////
@@ -1436,14 +1398,6 @@ class TranslatorChinesetraditional : public TranslatorAdapter_1_8_0
 // new since 1.3.3
 //////////////////////////////////////////////////////////////////////////
 
-    /*! When the search engine is enabled this text is put in the header
-     *  of each page before the field where one can enter the text to search
-     *  for.
-     */
-    virtual QCString trSearchForIndex()
-    {
-      return "搜尋索引";
-    }
     /*! This string is used as the title for the page listing the search
      *  results.
      */
@@ -1493,7 +1447,7 @@ class TranslatorChinesetraditional : public TranslatorAdapter_1_8_0
     {
       return filename + " 原始程式檔";
     }
-    
+
 //////////////////////////////////////////////////////////////////////////
 // new since 1.3.9
 //////////////////////////////////////////////////////////////////////////
@@ -1516,7 +1470,7 @@ class TranslatorChinesetraditional : public TranslatorAdapter_1_8_0
     virtual QCString trDirectories()
     { return "目錄"; }
 
-    /*! This returns a sentences that introduces the directory hierarchy. 
+    /*! This returns a sentences that introduces the directory hierarchy.
      *  and the fact that it is sorted alphabetically per level
      */
     virtual QCString trDirDescription()
@@ -1536,7 +1490,7 @@ class TranslatorChinesetraditional : public TranslatorAdapter_1_8_0
     {
       return QCString("目錄");
     }
-    
+
 //////////////////////////////////////////////////////////////////////////
 // new since 1.4.1
 //////////////////////////////////////////////////////////////////////////
@@ -1563,12 +1517,12 @@ class TranslatorChinesetraditional : public TranslatorAdapter_1_8_0
 //////////////////////////////////////////////////////////////////////////
 // new since 1.5.4 (mainly for Fortran)
 //////////////////////////////////////////////////////////////////////////
-    
+
     /*! header that is put before the list of member subprograms (Fortran). */
     virtual QCString trMemberFunctionDocumentationFortran()
     { return "成員函數/子程序 文件"; }
 
-    /*! This is put above each page as a link to the list of annotated data types (Fortran). */    
+    /*! This is put above each page as a link to the list of annotated data types (Fortran). */
     virtual QCString trCompoundListFortran()
     { return "資料型態列表"; }
 
@@ -1590,18 +1544,18 @@ class TranslatorChinesetraditional : public TranslatorAdapter_1_8_0
       }
       result+="資料型別成員函數";
       result+=" 附帶連結到 ";
-      if (!extractAll) 
+      if (!extractAll)
       {
          result+="每個成員函數的資料結構文件";
       }
-      else 
+      else
       {
          result+="他們屬於的資料型別";
       }
       return result;
     }
 
-    /*! This is used in LaTeX as the title of the chapter with the 
+    /*! This is used in LaTeX as the title of the chapter with the
      * annotated compound index (Fortran).
      */
     virtual QCString trCompoundIndexFortran()
@@ -1613,24 +1567,24 @@ class TranslatorChinesetraditional : public TranslatorAdapter_1_8_0
     virtual QCString trTypeDocumentation()
     { return "資料型別文件"; }
 
-    /*! This is used in the documentation of a file as a header before the 
+    /*! This is used in the documentation of a file as a header before the
      *  list of (global) subprograms (Fortran).
      */
     virtual QCString trSubprograms()
     { return "函數/子程序"; }
 
-    /*! This is used in the documentation of a file/namespace before the list 
+    /*! This is used in the documentation of a file/namespace before the list
      *  of documentation blocks for subprograms (Fortran)
      */
     virtual QCString trSubprogramDocumentation()
     { return "函數/子程序 文件"; }
 
-    /*! This is used in the documentation of a file/namespace/group before 
+    /*! This is used in the documentation of a file/namespace/group before
      *  the list of links to documented compounds (Fortran)
      */
      virtual QCString trDataTypes()
     { return "資料型別"; }
-    
+
     /*! used as the title of page containing all the index of all modules (Fortran). */
     virtual QCString trModulesList()
     { return "模組列表"; }
@@ -1659,6 +1613,7 @@ class TranslatorChinesetraditional : public TranslatorAdapter_1_8_0
         case ClassDef::Protocol:   result+="協議"; break;
         case ClassDef::Category:   result+="分類"; break;
         case ClassDef::Exception:  result+="例外"; break;
+        default: break;
       }
       if (isTemplate) result+=" Template";
       result+="參考文件";
@@ -1671,42 +1626,42 @@ class TranslatorChinesetraditional : public TranslatorAdapter_1_8_0
       result+="模組參考文件";
       return result;
     }
-    
+
     /*! This is put above each page as a link to all members of modules. (Fortran) */
     virtual QCString trModulesMembers()
     { return "模組成員"; }
 
     /*! This is an introduction to the page with all modules members (Fortran) */
     virtual QCString trModulesMemberDescription(bool extractAll)
-    { 
+    {
       QCString result="此處列出所有";
       if (!extractAll) result+="有文件的";
       result+="模組成員附帶連結到";
-      if (extractAll) 
+      if (extractAll)
       {
         result+="每個函數的模組文件:";
       }
-      else 
+      else
       {
         result+="他們所屬的模組:";
       }
       return result;
     }
 
-    /*! This is used in LaTeX as the title of the chapter with the 
+    /*! This is used in LaTeX as the title of the chapter with the
      *  index of all modules (Fortran).
      */
     virtual QCString trModulesIndex()
     { return "模組索引"; }
-    
+
     /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names 
+     *  be followed by a single name or by a list of names
      *  of the category.
      */
     virtual QCString trModule(bool /* first_capital */, bool /* singular */)
-    {       
+    {
       QCString result("模組");
-      return result; 
+      return result;
     }
     /*! This is put at the bottom of a module documentation page and is
      *  followed by a list of files that were used to generate the page.
@@ -1725,27 +1680,28 @@ class TranslatorChinesetraditional : public TranslatorAdapter_1_8_0
         case ClassDef::Protocol:   result+="協議"; break;
         case ClassDef::Category:   result+="分類"; break;
         case ClassDef::Exception:  result+="例外"; break;
+        default: break;
       }
       result+="文件由下列檔案產生";
       return result;
     }
     /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names 
+     *  be followed by a single name or by a list of names
      *  of the category.
      */
     virtual QCString trType(bool /* first_capital */, bool /* singular */)
-    { 
+    {
       QCString result("型別");
-      return result; 
+      return result;
     }
     /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names 
+     *  be followed by a single name or by a list of names
      *  of the category.
      */
     virtual QCString trSubprogram(bool /* first_capital */, bool /* singular */)
-    { 
+    {
       QCString result("子程式");
-      return result; 
+      return result;
     }
 
     /*! C# Type Constraint list */
@@ -1753,7 +1709,7 @@ class TranslatorChinesetraditional : public TranslatorAdapter_1_8_0
     {
       return "型別限制條件";
     }
-	
+
 //////////////////////////////////////////////////////////////////////////
 // new since 1.6.0 (mainly for the new search engine)
 //////////////////////////////////////////////////////////////////////////
@@ -1792,12 +1748,6 @@ class TranslatorChinesetraditional : public TranslatorAdapter_1_8_0
 // new since 1.6.3 (missing items for the directory pages)
 //////////////////////////////////////////////////////////////////////////
 
-    /*! introduction text for the directory dependency graph */
-    virtual QCString trDirDependency(const char *name)
-    {
-      return (QCString)name+"的目錄關連圖";
-    }
-
     /*! when clicking a directory dependency label, a page with a
      *  table is shown. The heading for the first column mentions the
      *  source file that has a relation to another file.
@@ -1816,7 +1766,7 @@ class TranslatorChinesetraditional : public TranslatorAdapter_1_8_0
       return (QCString)"含入檔案在"+name;
     }
 
-    /** Compiles a date string. 
+    /** Compiles a date string.
      *  @param year Year in 4 digits
      *  @param month Month of the year: 1=January
      *  @param day Day of the Month: 1..31
@@ -1859,6 +1809,165 @@ class TranslatorChinesetraditional : public TranslatorAdapter_1_8_0
     virtual QCString trDirDepGraph(const char *name)
     { return QCString(name)+"的目錄關連圖"+":"; }
 
+//////////////////////////////////////////////////////////////////////////
+// new since 1.8.0
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Detail level selector shown for hierarchical indices */
+    virtual QCString trDetailLevel()
+    { return "詳細程度"; }
+
+    /*! Section header for list of template parameters */
+    virtual QCString trTemplateParameters()
+    { return "樣版參數"; }
+
+    /*! Used in dot graph when UML_LOOK is enabled and there are many fields */
+    virtual QCString trAndMore(const QCString &number)
+    { return "及 "+number+" 個更多..."; }
+
+    /*! Used file list for a Java enum */
+    virtual QCString trEnumGeneratedFromFiles(bool single)
+    { QCString result = "此列舉型態的文件是由下列檔案所產生";
+      if (!single) result += "";
+      result+=":";
+      return result;
+    }
+
+    /*! Header of a Java enum page (Java enums are represented as classes). */
+    virtual QCString trEnumReference(const char *name)
+    { return QCString(name)+" 列舉型態參考"; }
+
+    /*! Used for a section containing inherited members */
+    virtual QCString trInheritedFrom(const char *members,const char *what)
+    { return QCString(members)+" 繼承自 "+what; }
+
+    /*! Header of the sections with inherited members specific for the
+     *  base class(es)
+     */
+    virtual QCString trAdditionalInheritedMembers()
+    { return "額外的繼承成員"; }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.8.2
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used as a tooltip for the toggle button that appears in the
+     *  navigation tree in the HTML output when GENERATE_TREEVIEW is
+     *  enabled. This tooltip explains the meaning of the button.
+     */
+    virtual QCString trPanelSynchronisationTooltip(bool enable)
+    {
+      QCString opt = enable ? "啟用" : "停用";
+      return "點擊 "+opt+" 面板進行同步";
+    }
+
+    /*! Used in a method of an Objective-C class that is declared in a
+     *  a category. Note that the @1 marker is required and is replaced
+     *  by a link.
+     */
+    virtual QCString trProvidedByCategory()
+    {
+      return "由 @1 分類所提供.";
+    }
+
+    /*! Used in a method of an Objective-C category that extends a class.
+     *  Note that the @1 marker is required and is replaced by a link to
+     *  the class method.
+     */
+    virtual QCString trExtendsClass()
+    {
+      return "延伸 @1 類別 .";
+    }
+
+    /*! Used as the header of a list of class methods in Objective-C.
+     *  These are similar to static public member functions in C++.
+     */
+    virtual QCString trClassMethods()
+    {
+      return "類別方法";
+    }
+
+    /*! Used as the header of a list of instance methods in Objective-C.
+     *  These are similar to public member functions in C++.
+     */
+    virtual QCString trInstanceMethods()
+    {
+      return "實體方法";
+    }
+
+    /*! Used as the header of the member functions of an Objective-C class.
+     */
+    virtual QCString trMethodDocumentation()
+    {
+      return "方法文件";
+    }
+
+    /*! Used as the title of the design overview picture created for the
+     *  VHDL output.
+     */
+    virtual QCString trDesignOverview()
+    {
+      return "設計概述";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.8.4
+//////////////////////////////////////////////////////////////////////////
+
+    /** old style UNO IDL services: implemented interfaces */
+    virtual QCString trInterfaces()
+    { return "導出介面"; }
+
+    /** old style UNO IDL services: inherited services */
+    virtual QCString trServices()
+    { return "引入的服務"; }
+
+    /** UNO IDL constant groups */
+    virtual QCString trConstantGroups()
+    { return "常數群組"; }
+
+    /** UNO IDL constant groups */
+    virtual QCString trConstantGroupReference(const char *namespaceName)
+    {
+      QCString result=namespaceName;
+      result+="常數群組參考";
+      return result;
+    }
+    /** UNO IDL service page title */
+    virtual QCString trServiceReference(const char *sName)
+    {
+      QCString result=(QCString)sName;
+      result+="服務參考";
+      return result;
+    }
+    /** UNO IDL singleton page title */
+    virtual QCString trSingletonReference(const char *sName)
+    {
+      QCString result=(QCString)sName;
+      result+="Singleton參考";
+      return result;
+    }
+    /** UNO IDL service page */
+    virtual QCString trServiceGeneratedFromFiles(bool single)
+    {
+      // single is true implies a single file
+      QCString result=(QCString)"本服務的文件由以下的檔案"
+                                "所產生";
+      if (single) result+=":"; else result+=":";
+      return result;
+    }
+    /** UNO IDL singleton page */
+    virtual QCString trSingletonGeneratedFromFiles(bool single)
+    {
+      // single is true implies a single file
+      QCString result=(QCString)"本singleton的文件由下面的檔案"
+                                "所產生";
+      if (single) result+=":"; else result+=":";
+      return result;
+    }
+
+//////////////////////////////////////////////////////////////////////////
+
 };
 
 #endif
