@@ -1,9 +1,9 @@
 /******************************************************************************
  *
- * $Id: $
+ * 
  *
  *
- * Copyright (C) 1997-2012 by Dimitri van Heesch.
+ * Copyright (C) 1997-2015 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -16,6 +16,8 @@
  *
  */
 
+#include <qfileinfo.h> 
+
 #include "xmldocvisitor.h"
 #include "docparser.h"
 #include "language.h"
@@ -25,8 +27,61 @@
 #include "dot.h"
 #include "message.h"
 #include "util.h"
-#include <qfileinfo.h> 
 #include "parserintf.h"
+#include "filename.h"
+#include "config.h"
+#include "htmlentity.h"
+
+static void visitCaption(XmlDocVisitor *parent, QList<DocNode> children)
+{
+  QListIterator<DocNode> cli(children);
+  DocNode *n;
+  for (cli.toFirst();(n=cli.current());++cli) n->accept(parent);
+}
+
+static void visitPreStart(FTextStream &t, const char *cmd, const bool doCaption, 
+                          XmlDocVisitor *parent, QList<DocNode> children, 
+                          const QCString &name, bool writeType, DocImage::Type type, const QCString &width, 
+                          const QCString &height)
+{
+  t << "<" << cmd;
+  if (writeType)
+  {
+    t << " type=\"";
+    switch(type)
+    {
+      case DocImage::Html:    t << "html"; break;
+      case DocImage::Latex:   t << "latex"; break;
+      case DocImage::Rtf:     t << "rtf"; break;
+      case DocImage::DocBook: t << "docbook"; break;
+    }
+    t << "\"";
+  }
+  if (!name.isEmpty())
+  {
+    t << " name=\"" << name << "\"";
+  }
+  if (!width.isEmpty())
+  {
+    t << " width=\"" << convertToXML(width) << "\"";
+  }
+  else if (!height.isEmpty())
+  {
+    t << " height=\"" << convertToXML(height) << "\"";
+  }
+  if (doCaption)
+  {
+    t << " caption=\"";
+    visitCaption(parent, children);
+    t << "\"";
+  }
+  t << ">";
+}
+
+static void visitPostEnd(FTextStream &t, const char *cmd)
+{
+  t << "</" << cmd << ">" << endl;
+}
 
 XmlDocVisitor::XmlDocVisitor(FTextStream &t,CodeOutputInterface &ci) 
   : DocVisitor(DocVisitor_XML), m_t(t), m_ci(ci), m_insidePre(FALSE), m_hide(FALSE) 
@@ -67,42 +122,14 @@ void XmlDocVisitor::visit(DocWhiteSpace *w)
 void XmlDocVisitor::visit(DocSymbol *s)
 {
   if (m_hide) return;
-  switch(s->symbol())
+  const char *res = HtmlEntityMapper::instance()->xml(s->symbol());
+  if (res)
   {
-    case DocSymbol::BSlash:  m_t << "\\"; break;
-    case DocSymbol::At:      m_t << "@"; break;
-    case DocSymbol::Less:    m_t << "&lt;"; break;
-    case DocSymbol::Greater: m_t << "&gt;"; break;
-    case DocSymbol::Amp:     m_t << "&amp;"; break;
-    case DocSymbol::Dollar:  m_t << "$"; break;
-    case DocSymbol::Hash:    m_t << "#"; break;
-    case DocSymbol::DoubleColon: m_t << "::"; break;
-    case DocSymbol::Percent: m_t << "%"; break;
-    case DocSymbol::Copy:    m_t << "<copy/>"; break;
-    case DocSymbol::Tm:      m_t << "<trademark/>"; break;
-    case DocSymbol::Reg:     m_t << "<registered/>"; break;
-    case DocSymbol::Apos:    m_t << "'"; break;
-    case DocSymbol::Quot:    m_t << "\""; break;
-    case DocSymbol::Lsquo:   m_t << "<lsquo/>"; break;
-    case DocSymbol::Rsquo:   m_t << "<rsquo/>"; break;
-    case DocSymbol::Ldquo:   m_t << "<ldquo/>"; break;
-    case DocSymbol::Rdquo:   m_t << "<rdquo/>"; break;
-    case DocSymbol::Ndash:   m_t << "<ndash/>"; break;
-    case DocSymbol::Mdash:   m_t << "<mdash/>"; break;
-    case DocSymbol::Uml:     m_t << "<umlaut char=\"" << s->letter() << "\"/>"; break;
-    case DocSymbol::Acute:   m_t << "<acute char=\"" << s->letter() << "\"/>"; break;
-    case DocSymbol::Grave:   m_t << "<grave char=\"" << s->letter() << "\"/>"; break;
-    case DocSymbol::Circ:    m_t << "<circ char=\"" << s->letter() << "\"/>"; break;
-    case DocSymbol::Tilde:   m_t << "<tilde char=\"" << s->letter() << "\"/>"; break;
-    case DocSymbol::Szlig:   m_t << "<szlig/>"; break;
-    case DocSymbol::Cedil:   m_t << "<cedil char=\"" << s->letter() << "\"/>"; break;
-    case DocSymbol::Ring:    m_t << "<ring char=\"" << s->letter() << "\"/>"; break;
-    case DocSymbol::Slash:   m_t << "<slash char=\"" << s->letter() << "\"/>"; break;
-    case DocSymbol::Nbsp:    m_t << "<nonbreakablespace/>"; break;
-    case DocSymbol::Aelig:   m_t << "<aelig/>"; break;
-    case DocSymbol::AElig:   m_t << "<AElig/>"; break;
-    default:
-                             err("error: unknown symbol found\n");
+    m_t << res;
+  }
+  else
+  {
+    err("XML: non supported HTML-entity found: %s\n",HtmlEntityMapper::instance()->html(s->symbol(),TRUE));
   }
 }
 
@@ -175,12 +202,18 @@ void XmlDocVisitor::visit(DocStyleChange *s)
 void XmlDocVisitor::visit(DocVerbatim *s)
 {
   if (m_hide) return;
+  QCString lang = m_langExt;
+  if (!s->language().isEmpty()) // explicit language setting
+  {
+    lang = s->language();
+  }
+  SrcLangExt langExt = getLanguageFromFileName(lang);
   switch(s->type())
   {
     case DocVerbatim::Code: // fall though
       m_t << "<programlisting>"; 
-      Doxygen::parserManager->getParser(m_langExt)
-                            ->parseCode(m_ci,s->context(),s->text(),
+      Doxygen::parserManager->getParser(lang)
+                            ->parseCode(m_ci,s->context(),s->text(),langExt,
                                         s->isExample(),s->exampleFile());
       m_t << "</programlisting>"; 
       break;
@@ -212,15 +245,25 @@ void XmlDocVisitor::visit(DocVerbatim *s)
     case DocVerbatim::XmlOnly: 
       m_t << s->text();
       break;
-    case DocVerbatim::Dot: 
-      m_t << "<dot>";
+    case DocVerbatim::DocbookOnly:
+      m_t << "<docbookonly>";
       filter(s->text());
-      m_t << "</dot>";
+      m_t << "</docbookonly>";
       break;
-    case DocVerbatim::Msc: 
-      m_t << "<msc>";
+    case DocVerbatim::Dot:
+      visitPreStart(m_t, "dot", s->hasCaption(), this, s->children(), QCString(""), FALSE, DocImage::Html, s->width(), s->height());
       filter(s->text());
-      m_t << "</msc>";
+      visitPostEnd(m_t, "dot");
+      break;
+    case DocVerbatim::Msc:
+      visitPreStart(m_t, "msc", s->hasCaption(), this, s->children(),  QCString(""), FALSE, DocImage::Html, s->width(), s->height());
+      filter(s->text());
+      visitPostEnd(m_t, "msc");
+      break;
+    case DocVerbatim::PlantUML:
+      visitPreStart(m_t, "plantuml", s->hasCaption(), this, s->children(),  QCString(""), FALSE, DocImage::Html, s->width(), s->height());
+      filter(s->text());
+      visitPostEnd(m_t, "plantuml");
       break;
   }
 }
@@ -234,6 +277,7 @@ void XmlDocVisitor::visit(DocAnchor *anc)
 void XmlDocVisitor::visit(DocInclude *inc)
 {
   if (m_hide) return;
+  SrcLangExt langExt = getLanguageFromFileName(inc->extension());
   switch(inc->type())
   {
     case DocInclude::IncWithLines:
@@ -244,6 +288,7 @@ void XmlDocVisitor::visit(DocInclude *inc)
          Doxygen::parserManager->getParser(inc->extension())
                                ->parseCode(m_ci,inc->context(),
                                            inc->text(),
+                                           langExt,
                                            inc->isExample(),
                                            inc->exampleFile(), &fd);
          m_t << "</programlisting>"; 
@@ -254,6 +299,7 @@ void XmlDocVisitor::visit(DocInclude *inc)
       Doxygen::parserManager->getParser(inc->extension())
                             ->parseCode(m_ci,inc->context(),
                                         inc->text(),
+                                        langExt,
                                         inc->isExample(),
                                         inc->exampleFile());
       m_t << "</programlisting>"; 
@@ -265,6 +311,11 @@ void XmlDocVisitor::visit(DocInclude *inc)
       filter(inc->text());
       m_t << "</htmlonly>";
       break;
+    case DocInclude::LatexInclude:
+      m_t << "<latexonly>";
+      filter(inc->text());
+      m_t << "</latexonly>";
+      break;
     case DocInclude::VerbInclude: 
       m_t << "<verbatim>";
       filter(inc->text());
@@ -276,6 +327,7 @@ void XmlDocVisitor::visit(DocInclude *inc)
                             ->parseCode(m_ci,
                                         inc->context(),
                                         extractBlock(inc->text(),inc->blockId()),
+                                        langExt,
                                         inc->isExample(),
                                         inc->exampleFile()
                                        );
@@ -297,6 +349,7 @@ void XmlDocVisitor::visit(DocIncOperator *op)
     pushEnabled();
     m_hide = TRUE;
   }
+  SrcLangExt langExt = getLanguageFromFileName(m_langExt);
   if (op->type()!=DocIncOperator::Skip) 
   {
     popEnabled();
@@ -304,7 +357,7 @@ void XmlDocVisitor::visit(DocIncOperator *op)
     {
       Doxygen::parserManager->getParser(m_langExt)
                             ->parseCode(m_ci,op->context(),
-                                        op->text(),op->isExample(),
+                                        op->text(),langExt,op->isExample(),
                                         op->exampleFile());
     }
     pushEnabled();
@@ -340,9 +393,13 @@ void XmlDocVisitor::visit(DocIndexEntry *ie)
          "</indexentry>";
 }
 
-void XmlDocVisitor::visit(DocSimpleSectSep *)
+void XmlDocVisitor::visit(DocSimpleSectSep *sep)
 {
-  m_t << "<simplesectsep/>";
+  if (sep->parent() && sep->parent()->kind()==DocNode::Kind_SimpleSect)
+  {
+    visitPost((DocSimpleSect*)sep->parent()); // end current section
+    visitPre((DocSimpleSect*)sep->parent());  // start new section
+  }
 }
 
 void XmlDocVisitor::visit(DocCite *cite)
@@ -511,7 +568,7 @@ void XmlDocVisitor::visitPre(DocSection *s)
   if (!s->anchor().isEmpty()) m_t << "_1" << s->anchor();
   m_t << "\">" << endl;
   m_t << "<title>";
-  filter(s->title());
+  filter(convertCharEntitiesToUTF8(s->title()));
   m_t << "</title>" << endl;
 }
 
@@ -650,7 +707,9 @@ void XmlDocVisitor::visitPost(DocInternal *)
 void XmlDocVisitor::visitPre(DocHRef *href)
 {
   if (m_hide) return;
-  m_t << "<ulink url=\"" << href->url() << "\">";
+  m_t << "<ulink url=\"";
+  filter(href->url());
+  m_t << "\">";
 }
 
 void XmlDocVisitor::visitPost(DocHRef *) 
@@ -674,14 +733,6 @@ void XmlDocVisitor::visitPost(DocHtmlHeader *)
 void XmlDocVisitor::visitPre(DocImage *img)
 {
   if (m_hide) return;
-  m_t << "<image type=\"";
-  switch(img->type())
-  {
-    case DocImage::Html:  m_t << "html"; break;
-    case DocImage::Latex: m_t << "latex"; break;
-    case DocImage::Rtf:   m_t << "rtf"; break;
-  }
-  m_t << "\"";
 
   QCString baseName=img->name();
   int i;
@@ -689,20 +740,7 @@ void XmlDocVisitor::visitPre(DocImage *img)
   {
     baseName=baseName.right(baseName.length()-i-1);
   }
-  m_t << " name=\"" << baseName << "\"";
-  if (!img->width().isEmpty())
-  {
-    m_t << " width=\"";
-    filter(img->width());
-    m_t << "\"";
-  }
-  else if (!img->height().isEmpty())
-  {
-    m_t << " height=\"";
-    filter(img->height());
-    m_t << "\"";
-  }
-  m_t << ">";
+  visitPreStart(m_t, "image", FALSE, this, img->children(), baseName, TRUE, img->type(), img->width(), img->height());
 
   // copy the image to the output dir
   QFile inImage(img->name());
@@ -723,32 +761,45 @@ void XmlDocVisitor::visitPre(DocImage *img)
 void XmlDocVisitor::visitPost(DocImage *) 
 {
   if (m_hide) return;
-  m_t << "</image>" << endl;
+  visitPostEnd(m_t, "image");
 }
 
 void XmlDocVisitor::visitPre(DocDotFile *df)
 {
   if (m_hide) return;
-  m_t << "<dotfile name=\"" << df->file() << "\">";
+  visitPreStart(m_t, "dotfile", FALSE, this, df->children(), df->file(), FALSE, DocImage::Html, df->width(), df->height());
 }
 
 void XmlDocVisitor::visitPost(DocDotFile *) 
 {
   if (m_hide) return;
-  m_t << "</dotfile>" << endl;
+  visitPostEnd(m_t, "dotfile");
 }
 
 void XmlDocVisitor::visitPre(DocMscFile *df)
 {
   if (m_hide) return;
-  m_t << "<mscfile name=\"" << df->file() << "\">";
+  visitPreStart(m_t, "mscfile", FALSE, this, df->children(), df->file(), FALSE, DocImage::Html, df->width(), df->height());
 }
 
 void XmlDocVisitor::visitPost(DocMscFile *) 
 {
   if (m_hide) return;
-  m_t << "</mscfile>" << endl;
+  visitPostEnd(m_t, "mscfile");
 }
+
+void XmlDocVisitor::visitPre(DocDiaFile *df)
+{
+  if (m_hide) return;
+  visitPreStart(m_t, "diafile", FALSE, this, df->children(), df->file(), FALSE, DocImage::Html, df->width(), df->height());
+}
+
+void XmlDocVisitor::visitPost(DocDiaFile *)
+{
+  if (m_hide) return;
+  visitPostEnd(m_t, "diafile");
+}
+
 void XmlDocVisitor::visitPre(DocLink *lnk)
 {
   if (m_hide) return;
@@ -764,7 +815,10 @@ void XmlDocVisitor::visitPost(DocLink *)
 void XmlDocVisitor::visitPre(DocRef *ref)
 {
   if (m_hide) return;
-   if (!ref->file().isEmpty()) startLink(ref->ref(),ref->file(),ref->anchor());
+  if (!ref->file().isEmpty()) 
+  {
+    startLink(ref->ref(),ref->file(),ref->isSubPage() ? QCString() : ref->anchor());
+  }
   if (!ref->hasLinkText()) filter(ref->targetTitle());
 }
 
@@ -909,6 +963,7 @@ void XmlDocVisitor::visitPost(DocParamList *)
 void XmlDocVisitor::visitPre(DocXRefItem *x)
 {
   if (m_hide) return;
+  if (x->title().isEmpty()) return;
   m_t << "<xrefsect id=\"";
   m_t << x->file() << "_1" << x->anchor();
   m_t << "\">";
@@ -918,9 +973,10 @@ void XmlDocVisitor::visitPre(DocXRefItem *x)
   m_t << "<xrefdescription>";
 }
 
-void XmlDocVisitor::visitPost(DocXRefItem *)
+void XmlDocVisitor::visitPost(DocXRefItem *x)
 {
   if (m_hide) return;
+  if (x->title().isEmpty()) return;
   m_t << "</xrefdescription>";
   m_t << "</xrefsect>";
 }
@@ -970,6 +1026,26 @@ void XmlDocVisitor::visitPost(DocHtmlBlockQuote *)
   m_t << "</blockquote>";
 }
 
+void XmlDocVisitor::visitPre(DocVhdlFlow *)
+{
+}
+
+void XmlDocVisitor::visitPost(DocVhdlFlow *)
+{
+}
+
+void XmlDocVisitor::visitPre(DocParBlock *)
+{
+  if (m_hide) return;
+  m_t << "<parblock>";
+}
+
+void XmlDocVisitor::visitPost(DocParBlock *)
+{
+  if (m_hide) return;
+  m_t << "</parblock>";
+}
+
 
 void XmlDocVisitor::filter(const char *str)
 { 
@@ -978,6 +1054,7 @@ void XmlDocVisitor::filter(const char *str)
 
 void XmlDocVisitor::startLink(const QCString &ref,const QCString &file,const QCString &anchor)
 {
+  //printf("XmlDocVisitor: file=%s anchor=%s\n",file.data(),anchor.data());
   m_t << "<ref refid=\"" << file;
   if (!anchor.isEmpty()) m_t << "_1" << anchor;
   m_t << "\" kindref=\"";
